@@ -88,7 +88,9 @@ def get_pv_power_from_database(
     db_connection = DatabaseConnection(url=url, base=Base_PV)
 
     with db_connection.get_session() as session:
-        pv_yields: List[PVYieldSQL] = get_pv_yield(session=session, start_utc=start_utc_extra)
+        pv_yields: List[PVYieldSQL] = get_pv_yield(
+            session=session, start_utc=start_utc_extra, correct_data=True
+        )
 
         logger.debug(f"Found {len(pv_yields)} PV yields from the database")
 
@@ -120,17 +122,21 @@ def get_pv_power_from_database(
 
     pv_yields_df.columns = encode_label(pv_yields_df.columns, label="pvoutput")
 
+    # we are going interpolate using 'quadratic' method and we need at least 3 data points,
+    # therefore we drop system wiht less than 3 nans
+    pv_yields_df = pv_yields_df.loc[:, pv_yields_df.notnull().sum() >= 3]
+
     # interpolate in between, maximum 'live_interpolate_minutes' mins
     # note data is in 5 minutes chunks
     pv_yields_df = empty_df.join(pv_yields_df)
     limit = int(interpolate_minutes / 5)
     if limit > 0:
         try:
-            pv_yields_df.interpolate(limit=limit, inplace=True, method="cubic")
+            pv_yields_df.interpolate(limit=limit, inplace=True, method="quadratic")
         except Exception as e:
             logger.exception(e)
             logger.debug(pv_yields_df)
-            raise Exception(f"Could not do cubic interpolate with limit {limit}")
+            raise Exception(f"Could not do interpolate with limit {limit}")
 
     # filter out the extra minutes loaded
     logger.debug(f"{len(pv_yields_df)} of datetimes before filter on {start_utc}")
